@@ -64,10 +64,11 @@ def translate_lines_with_same_context(translate_client,
 
     ans_new2 = list(map(lambda x: x.replace(splat_end, ''), as_lines))
     as_new_3 = '\n'.join(ans_new2)
-    return as_new_3
+    return as_new_3.replace('&#39;', '\'').replace('&amp;', '&')
 
 
-    # translate
+
+# translate
     parent = f'projects/{project_id}'
     text_type = "plain" if html_or_normal_text == 'normal_text' else 'html'
     try:
